"""Unofficial Honda Connect Europe (My Honda+) API client library."""

from .api import AuthTokens, HondaAPI, HondaAPIError, compute_trip_stats, parse_charge_schedule, parse_climate_schedule, parse_ev_status
from .auth import DeviceKey, HondaAuth, encrypt_request
from .storage import SecretStorage, get_storage

__all__ = [
    "AuthTokens",
    "HondaAPI",
    "HondaAPIError",
    "compute_trip_stats",
    "parse_charge_schedule",
    "parse_climate_schedule",
    "parse_ev_status",
    "DeviceKey",
    "HondaAuth",
    "encrypt_request",
    "SecretStorage",
    "get_storage",
]
